.. :changelog:

History
-------


0.0.3 (2015-05-04)
++++++++++++++++++

* Add type filter to charmstore search.


0.0.2 (2015-04-08)
++++++++++++++++++

* Add series filter to charmstore search.
* Handle 407 http error from charmstore as EntityNotFound.
* Add simple usage example to README.
* Minor changes to HACKING.
* Minor fixes.


0.0.1 (2015-03-19)
++++++++++++++++++

* Initial release.
